define(
//begin v1.x content
{
	"HKD_displayName": "hongkongsk dollar",
	"CHF_displayName": "schweizerfranc",
	"CHF_symbol": "CHF",
	"JPY_symbol": "JP¥",
	"CAD_displayName": "canadisk dollar",
	"HKD_symbol": "HK$",
	"CNY_displayName": "kinesisk yuan",
	"AUD_displayName": "australsk dollar",
	"JPY_displayName": "japansk yen",
	"CAD_symbol": "CA$",
	"USD_displayName": "amerikansk dollar",
	"EUR_symbol": "€",
	"CNY_symbol": "CN¥",
	"GBP_displayName": "britisk pund",
	"GBP_symbol": "£",
	"AUD_symbol": "AU$",
	"EUR_displayName": "euro"
}
//end v1.x content
);